#
# Please submit bugfixes or comments via https://bugs.links2linux.org/
#
# Please edit xbmc.spec and xbmc.changes only. *-noX.* files are generated from xbmc.* files with the pre_checkin.sh script
#

%define _libtag_ver %(version="`rpm -q --qf '%{VERSION}' libtag-devel`"; echo "$version")

%bcond_without enable_rpi_build
%bcond_without enable_rpi_omxplayer

Name:           xbmc-noX
# xbmc can be built without X support when openGL ES is used (mainly used on ARM boards used as media center)
%define noX_build ("%{name}" == "xbmc-noX")
%if %{noX_build}
# no X build needs openGL ES
%bcond_with enable_opengl
%bcond_without enable_opengles
%else
%ifarch %arm armv6l armv6hl
%bcond_with enable_opengl
%bcond_without enable_opengles
%else
%bcond_without enable_opengl
%bcond_with enable_opengles
%endif
%endif
Version:        12.3
Release:        3.11
Summary:        XBMC Media center
License:        GPL-2.0+ and GPL-3.0+
Group:          Productivity/Multimedia/Video/Players
Url:            http://www.xbmc.org/
Source0:        http://mirrors.xbmc.org/releases/source/xbmc-%{version}.tar.gz
Source1:        https://github.com/opdenkamp/xbmc-pvr-addons/archive/frodo.zip
# PATCH-FIX-UPSTREAM xbmc-12.2-subtitles.patch -- already merged in git rev
Patch0:         xbmc-12.2-subtitles.patch
# PATCH-FIX-UPSTREAM samba4-fix.patch -- Fix path for libsmbclient.h shipped with samba4 -- already in master git.
Patch1:         samba4-fix.patch
Patch2:         git_rev.patch
Patch3:         pvr-addons-enable-all.patch
# Raspberry Pi (armv6) only: Fix include path for XBMCTex.cpp:38:25: fatal error: guilib/XBTF.h: No such file or directory
Patch4:         texture.patch
# omxplayer 3D support is only available for non X11 XBMC
Patch5:         disable_omxplayer_3d_support.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
ExcludeArch:    ppc64
%if %{noX_build}
Conflicts:      xbmc
%else
Conflicts:      xbmc-noX
%endif

%if 0%{?suse_version} < 1140
BuildRequires:  hal-devel
%endif
%if 0%{?fedora} >= 14
BuildRequires:  gettext-autopoint
%else
BuildRequires:  gettext
%endif
%ifarch armv6l armv6hl
%if %{with enable_rpi_build}
%if %{with enable_rpi_omxplayer}
BuildRequires:  omxplayer
%endif
%endif
%endif

BuildRequires:  avahi-devel
BuildRequires:  boost-devel
BuildRequires:  ccache
BuildRequires:  cmake
BuildRequires:  curl-devel
BuildRequires:  desktop-file-utils
BuildRequires:  doxygen
BuildRequires:  enca-devel
BuildRequires:  fdupes
BuildRequires:  ffmpeg1-devel
BuildRequires:  flac-devel
BuildRequires:  flex
BuildRequires:  fontconfig-devel
BuildRequires:  freetype2-devel
BuildRequires:  fribidi-devel
BuildRequires:  ftgl-devel
BuildRequires:  gcc-c++
%if %{with enable_opengl}
BuildRequires:  glew-devel
%endif
BuildRequires:  glibc-devel
BuildRequires:  gperf
BuildRequires:  java
BuildRequires:  libSDL-devel
BuildRequires:  libSDL_image-devel
BuildRequires:  libSDL_mixer-devel
BuildRequires:  libass-devel >= 0.9.7
BuildRequires:  libbluray-devel
BuildRequires:  libbz2-devel
BuildRequires:  libcdio-devel
BuildRequires:  libcec2-devel
%ifarch %ix86 x86_64
BuildRequires:  libcrystalhd-devel
%endif
BuildRequires:  libdca-devel
BuildRequires:  libdvdread-devel
BuildRequires:  libexpat-devel
BuildRequires:  libfaac-devel
BuildRequires:  libgcrypt-devel
BuildRequires:  libgpg-error-devel
BuildRequires:  libhdhomerun-devel
BuildRequires:  libjasper-devel
BuildRequires:  libjpeg-devel
BuildRequires:  libmad-devel
BuildRequires:  libmicrohttpd-devel
BuildRequires:  libmodplug-devel
BuildRequires:  libmpeg2-devel
BuildRequires:  libnfs-devel
BuildRequires:  libogg-devel
BuildRequires:  libpcrecpp0
BuildRequires:  libplist-devel
BuildRequires:  libpng-devel
BuildRequires:  libpulse-devel
BuildRequires:  librtmp-devel
BuildRequires:  libsamplerate-devel
BuildRequires:  libsmbclient-devel
BuildRequires:  libssh-devel
BuildRequires:  libstdc++-devel
BuildRequires:  libtag-devel >= 1.8
BuildRequires:  libtiff-devel
BuildRequires:  libtool
BuildRequires:  libudev-devel
%if %{with enable_opengl}
BuildRequires:  libvdpau-devel
%endif
BuildRequires:  libvorbis-devel
BuildRequires:  libyajl-devel
BuildRequires:  lzo-devel
BuildRequires:  mysql-devel
BuildRequires:  nasm
BuildRequires:  pcre-devel
BuildRequires:  pkg-config
BuildRequires:  python-devel
BuildRequires:  sqlite-devel
BuildRequires:  swig
BuildRequires:  tinyxml-devel
BuildRequires:  unzip
%if !%{noX_build}
BuildRequires:  xorg-x11-devel
%endif
BuildRequires:  yasm
BuildRequires:  zip
BuildRequires:  zlib-devel
BuildRequires:  pkgconfig(glib-2.0)
## xbmc needs the same libtag version which was used to build against
Requires:       libtag1 = %{_libtag_ver}
# glxinfo is needed to check hw accel
%if 0%{?suse_version} >= 1220
%if !%{noX_build}
Requires:       Mesa-demo-x
%endif
%endif
%if %{with enable_opengles}
%ifnarch armv6l armv6hl
BuildRequires:  Mesa-libEGL-devel
BuildRequires:  Mesa-libGLESv2-devel
%else
%if %{with enable_rpi_build}
BuildRequires:  raspberrypi-userland-devel
%else
BuildRequires:  Mesa-libEGL-devel
BuildRequires:  Mesa-libGLESv2-devel
%endif
%endif
%endif

%description
XBMC media center is a free cross-platform media-player jukebox and
entertainment hub.  XBMC can play a spectrum of of multimedia formats,
and featuring playlist, audio visualizations, slideshow, and weather
forecast functions, together third-party plugins.

%package devel
Summary:        XBMC Media center devel files
Group:          Development/Languages/C and C++
Requires:       %{name}
BuildArch:      noarch
%if %{noX_build}
Conflicts:      xbmc-devel
%else
Conflicts:      xbmc-noX-devel
%endif

%description devel
Development files for the XBMC media Center

%prep
%setup -q -n xbmc-%{version}-Frodo
%patch0 -p1
%patch2 -p0
%patch3 -p0
%patch4
%if !%{noX_build}
%patch5
%endif
%if 0%{?suse_version} >= 1310
%patch1 -p0
%endif
unzip -q %{S:1}
mv xbmc-pvr-addons-frodo pvr-addons
pushd pvr-addons
./bootstrap
popd
chmod +x bootstrap
./bootstrap

%build
export CPPFLAGS="-I/usr/include/ffmpeg"
export CFLAGS="%{optflags} -fPIC -I/usr/include/ffmpeg -D__STDC_CONSTANT_MACROS"
export CXXFLAGS="%{optflags} -fPIC -I/usr/include/ffmpeg -D__STDC_CONSTANT_MACROS"
export LDFLAGS="-fPIC"
export LIBS="-L%{_libdir}/mysql -lhdhomerun $LIBS"
export ASFLAGS=-fPIC
%ifarch armv6l armv6hl
%if %{with enable_rpi_build}
export CXXFLAGS="$CXXFLAGS -I%{_includedir}/interface/vcos/pthreads -I%{_includedir}/interface/vmcs_host/linux"
%endif
%endif
%configure \
--enable-libusb \
--enable-airplay \
--enable-external-libraries \
--enable-external-ffmpeg \
--enable-rtmp \
--enable-libbluray \
--disable-debug \
--disable-static \
--enable-libcec \
%if %{with enable_opengl}
  --enable-goom \
  --enable-vaapi \
  --enable-vdpau \
  --enable-gl \
%else
  --disable-goom \
  --disable-vaapi \
  --disable-vdpau \
  --disable-gl \
%endif
%if %{with enable_opengles}
  --enable-gles \
%else
  --disable-gles \
%endif
%ifarch armv6l armv6hl
%if %{with enable_rpi_build}
    --with-platform=raspberry-pi \
%if %{with enable_rpi_omxplayer}
      --enable-player=omxplayer \
%endif
%endif
%endif
%ifarch armv7l armv7hl
  --enable-tegra --disable-neon \
%endif
%if %{noX_build}
  --disable-x11 --disable-xrandr --disable-sdl --disable-joystick \
%endif

make %{?_smp_mflags} VERBOSE=1

%install

rm -rf $RPM_BUILD_ROOT
make DESTDIR=$RPM_BUILD_ROOT install
# remove the doc files from unversioned /usr/share/doc/xbmc, they should be in versioned docdir
rm -r %{buildroot}/%{_datadir}/doc/

# copy manpages
install -m 644 -D docs/manpages/xbmc-standalone.1 %{buildroot}%{_mandir}/man1/xbmc-standalone.1
install -m 644 -D docs/manpages/xbmc.bin.1 %{buildroot}%{_mandir}/man1/xbmc.1

desktop-file-install \
 --dir=%{buildroot}%{_datadir}/applications \
 %{buildroot}%{_datadir}/applications/xbmc.desktop

%fdupes %{buildroot}

%files
%defattr(-,root,root)
%doc copying.txt  LICENSE.GPL docs/README.linux
%{_bindir}/xbmc
%{_bindir}/xbmc-standalone
%{_libdir}/xbmc
#%%{_datadir}/xbmc
%{_datadir}/xsessions/XBMC.desktop
%{_datadir}/applications/xbmc.desktop
%{_datadir}/icons/hicolor/*/*/*.png
%{_mandir}/man1/xbmc-standalone.1.gz
%{_mandir}/man1/xbmc.1.gz

%{_datadir}/xbmc/FEH.py
%{_datadir}/xbmc/addons/metadata.album.universal/*
%{_datadir}/xbmc/addons/metadata.artists.universal/*
%{_datadir}/xbmc/addons/metadata.common.allmusic.com/*
%{_datadir}/xbmc/addons/metadata.common.amazon.de/*
%{_datadir}/xbmc/addons/metadata.common.fanart.tv/*
%{_datadir}/xbmc/addons/metadata.common.hdtrailers.net/*
%{_datadir}/xbmc/addons/metadata.common.htbackdrops.com/*
%{_datadir}/xbmc/addons/metadata.common.imdb.com/*
%{_datadir}/xbmc/addons/metadata.common.last.fm/*
%{_datadir}/xbmc/addons/metadata.common.musicbrainz.org/*
%{_datadir}/xbmc/addons/metadata.common.theaudiodb.com/*
%{_datadir}/xbmc/addons/metadata.common.themoviedb.org/*
%{_datadir}/xbmc/addons/metadata.musicvideos.theaudiodb.com/*
%{_datadir}/xbmc/addons/metadata.themoviedb.org/*
%{_datadir}/xbmc/addons/metadata.tvdb.com/*
%{_datadir}/xbmc/addons/repository.pvr-android.xbmc.org/*
%{_datadir}/xbmc/addons/repository.pvr-ios.xbmc.org/*
%{_datadir}/xbmc/addons/repository.pvr-osx32.xbmc.org/*
%{_datadir}/xbmc/addons/repository.pvr-osx64.xbmc.org/*
%{_datadir}/xbmc/addons/repository.pvr-win32.xbmc.org/*
%{_datadir}/xbmc/addons/repository.xbmc.org/*
%{_datadir}/xbmc/addons/screensaver.rsxs.euphoria/*
%{_datadir}/xbmc/addons/screensaver.rsxs.plasma/*
%{_datadir}/xbmc/addons/screensaver.rsxs.solarwinds/*
%{_datadir}/xbmc/addons/screensaver.xbmc.builtin.black/*
%{_datadir}/xbmc/addons/screensaver.xbmc.builtin.dim/*
%{_datadir}/xbmc/addons/script.module.pil/*
%{_datadir}/xbmc/addons/skin.confluence/*
%{_datadir}/xbmc/addons/visualization.dxspectrum/*
%{_datadir}/xbmc/addons/visualization.glspectrum/*
%if %{with enable_opengl}
%{_datadir}/xbmc/addons/visualization.goom/*
%endif
%{_datadir}/xbmc/addons/visualization.milkdrop/*
%{_datadir}/xbmc/addons/visualization.projectm/*
%{_datadir}/xbmc/addons/visualization.waveform/*
%{_datadir}/xbmc/addons/weather.wunderground/*
%{_datadir}/xbmc/addons/webinterface.default/*
%{_datadir}/xbmc/addons/xbmc.addon/*
%{_datadir}/xbmc/addons/xbmc.core/*
%{_datadir}/xbmc/addons/xbmc.gui/*
%{_datadir}/xbmc/addons/xbmc.json/*
%{_datadir}/xbmc/addons/xbmc.metadata/*
%{_datadir}/xbmc/addons/xbmc.pvr/*
%{_datadir}/xbmc/addons/xbmc.python/*
%{_datadir}/xbmc/addons/pvr.argustv/*
%{_datadir}/xbmc/addons/pvr.demo/*
%{_datadir}/xbmc/addons/pvr.dvbviewer/*
%{_datadir}/xbmc/addons/pvr.hts/*
%{_datadir}/xbmc/addons/pvr.iptvsimple/*
%{_datadir}/xbmc/addons/pvr.mediaportal.tvserver/*
%{_datadir}/xbmc/addons/pvr.mythtv.cmyth/*
%{_datadir}/xbmc/addons/pvr.nextpvr/*
%{_datadir}/xbmc/addons/pvr.njoy/*
%{_datadir}/xbmc/addons/pvr.vdr.vnsi/*
%{_datadir}/xbmc/addons/pvr.vuplus/*
%{_datadir}/xbmc/addons/pvr.wmc/*
%{_datadir}/xbmc/language/*
%{_datadir}/xbmc/media/*
%{_datadir}/xbmc/sounds/*
%{_datadir}/xbmc/system/*
%{_datadir}/xbmc/userdata/*

%files devel
%defattr(-,root,root)
%{_datadir}/xbmc/addons/library.xbmc.addon/dlfcn-win32.cpp
%{_datadir}/xbmc/addons/library.xbmc.addon/dlfcn-win32.h
%{_datadir}/xbmc/addons/library.xbmc.gui/libXBMC_gui.h
%{_datadir}/xbmc/addons/library.xbmc.addon/libXBMC_addon.h
%{_datadir}/xbmc/addons/library.xbmc.pvr/libXBMC_pvr.h

%changelog
* Mon Feb 17 2014 guillaume@opensuse.org
- Replace raspberrypi-gfx-devel package by raspberrypi-userland-devel
* Wed Feb 12 2014 guillaume@opensuse.org
- Add no X version support (mainly used by ARM boards)
  Fri Dec 27 08:44:21 UTC 2013 - sagiben at gmail dot com
- - New upstream version 12.3
* Wed Oct  2 2013 guillaume@opensuse.org
- Fix Raspberry Pi (armv6) build:
  * Add include path for raspberrypi-gfx headers
  * Add texture.patch to fix include path for XBMCTex.cpp
  * Add disable_omxplayer_3d_support.patch to disable 3D support
  from omxplayer since X11/GLES does not support it (only EGL)
* Mon Sep 16 2013 guillaume@opensuse.org
- Enable omxplayer by default (player for raspberry pi ARMv6 board)
* Mon Sep 16 2013 guillaume@opensuse.org
- Protect enable_rpi_build condition with %%ifarch armv6
  Mon Sep 16 03:06:17 UTC 2013 - sagiben at gmail dot com
- Enable MythTV pvr addon
- Set git revision
* Fri Sep 13 2013 guillaume@opensuse.org
- Add options to enable/disable openGL / openGL ES support
  * ARM default: openGL ES
  * Other arch: openGL
* Fri Sep 13 2013 guillaume@opensuse.org
- Add support for omxplayer for raspberry pi board (armv6)
* Mon Sep  9 2013 guillaume@opensuse.org
- Add support for Raspberry Pi ARM board (armv6)
* Mon Sep  9 2013 guillaume@opensuse.org
- Add libcec and airplay support
* Wed Sep  4 2013 fisiu@opensuse.org
- Add samba4-fix.patch: fix build against samba4 - enabled for
  openSUSE >= 13.1.
* Wed Sep  4 2013 fisiu@opensuse.org
- Add Requires: Mesa-demo-x for openSUSE >= 12.2, fix pm#84.
* Mon Aug 26 2013 guillaume@opensuse.org
- Make use of %%configure macro
* Fri Aug 23 2013 guillaume@opensuse.org
- Fix builds:
  * XBMC 12.2 depends on FFMPEG1, not FFMPEG2
  * crystalhd is only built for x86/x86_64
* Mon Jun  3 2013 fisiu@opensuse.org
- Add xbmc-12.2-subtitles.patch: embeded fonts' rendering fix.
  Fri May 10 16:35:39 UTC 2013 - sagiben at gmail dot com
- New upstream version 12.2
  Fri Mar 29 03:52:57 UTC 2013 - sagiben at gmail dot com
- New upstream version 12.1
* Mon Feb  4 2013 fisiu@opensuse.org
- Spec file cleanup.
- Enable support for airplay.
- Detect libtag version and use it as Requires.
* Sun Feb  3 2013 p.seiler@linuxmail.org
- small changes in the spec file for cleanness
  replaced BuildRequires to simple java
  removed outcommented stuff like BuildRequires and so on
* Fri Feb  1 2013 hvogel@opensuse.org
-Include PVR add-ons, they are the main feature of Frodo
* Fri Feb  1 2013 p.seiler@linuxmail.org
- added explizit libtag-devel 1.8 requirement to prevent conflict with openSUSE libtag package
* Thu Jan 31 2013 p.seiler@linuxmail.org
- corrected licenses in spec file to prevent build warning
- added devel package to prevent build error
* Wed Jan 30 2013 p.seiler@linuxmail.org
- new upstream version 12.0
  + HD audio support, including DTS-MA and Dolby True-HD, via the
  new XBMC AudioEngine
  + Live TV and PVR support
  + h.264 10bit (aka Hi10P) video software decoding for anime
  + Improved image support, allowing the database to accomodate
  numerous additional image types
  + Improved Airplay support across all platforms
  + Improved controller support
  + Advanced Filtering in the library
  + Advanced UPnP sharing
  + Translations now powered by Transifex
  Sun Apr  8 14:39:48 UTC 2012 - sagiben at gmail com
- New upstream version 11.0
* Fri Dec  9 2011 ismail@namtrac.org
- Remove _service its fragile
- Spec cleanup
* Thu Dec  8 2011 ismail@namtrac.org
- Depend on libbluray1
* Mon Nov 28 2011 sagiben@gmail.com
- fix build with gcc-4.6. Flags to the Linker must be passed via -Wl,.
  Patch was taken from xbmc ticket #11383, http://trac.xbmc.org/ticket/11383
* Tue May  3 2011 fisiu@opensuse.org
- disable-hal for openSUSE >= 11.4
* Fri Apr 15 2011 andrea@links2linux.de
- New upstream version 10.1
* Mon Jan 24 2011 andrea@links2linux.de
- enabled crystalhd and bluray support (dependencies now available)
* Mon Jan 24 2011 andrea@links2linux.de
- enabled VA-API (not sure if it works), FAAC, ssh, optimizations
* Wed Jan 12 2011 andrea@links2linux.de
- New upstream version 10.0 (Thanks fedora)
* Sun Feb  7 2010 andrea@links2linux.de
- fixed docs location
* Sat Feb  6 2010 andrea@links2linux.de
- added bool.patch to fix a startup segmentation fault
- do NOT use ffmpeg external libraries because they make xbmc crashes when you try to reproduce a video
